// This file is generated by kconfig_compiler_kf5 from kbrickbuster.kcfg.
// All changes you do to this file will be lost.
#ifndef SETTINGS_H
#define SETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class Settings : public KConfigSkeleton
{
  public:

    static Settings *self();
    ~Settings();

    /**
      Set Fire on mouse click
    */
    static
    void setFireOnClick( bool v )
    {
      if (!self()->isImmutable( QStringLiteral( "FireOnClick" ) ))
        self()->mFireOnClick = v;
    }

    /**
      Get Fire on mouse click
    */
    static
    bool fireOnClick()
    {
      return self()->mFireOnClick;
    }

  protected:
    Settings();
    friend class SettingsHelper;


    // General
    bool mFireOnClick;

  private:
};

#endif

