/****************************************************************************
** Meta object code from reading C++ file 'canvaswidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kbrickbuster-17.12.3/src/canvaswidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'canvaswidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_CanvasWidget_t {
    QByteArrayData data[28];
    char stringdata0[287];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_CanvasWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_CanvasWidget_t qt_meta_stringdata_CanvasWidget = {
    {
QT_MOC_LITERAL(0, 0, 12), // "CanvasWidget"
QT_MOC_LITERAL(1, 13, 13), // "levelComplete"
QT_MOC_LITERAL(2, 27, 0), // ""
QT_MOC_LITERAL(3, 28, 9), // "gameEnded"
QT_MOC_LITERAL(4, 38, 5), // "score"
QT_MOC_LITERAL(5, 44, 5), // "level"
QT_MOC_LITERAL(6, 50, 11), // "elapsedTime"
QT_MOC_LITERAL(7, 62, 9), // "focusLost"
QT_MOC_LITERAL(8, 72, 12), // "mousePressed"
QT_MOC_LITERAL(9, 85, 4), // "fire"
QT_MOC_LITERAL(10, 90, 14), // "cheatSkipLevel"
QT_MOC_LITERAL(11, 105, 12), // "cheatAddLife"
QT_MOC_LITERAL(12, 118, 13), // "setGamePaused"
QT_MOC_LITERAL(13, 132, 6), // "paused"
QT_MOC_LITERAL(14, 139, 18), // "updateFireShortcut"
QT_MOC_LITERAL(15, 158, 7), // "newGame"
QT_MOC_LITERAL(16, 166, 8), // "showLine"
QT_MOC_LITERAL(17, 175, 4), // "line"
QT_MOC_LITERAL(18, 180, 10), // "lineNumber"
QT_MOC_LITERAL(19, 191, 7), // "putGift"
QT_MOC_LITERAL(20, 199, 4), // "gift"
QT_MOC_LITERAL(21, 204, 5), // "times"
QT_MOC_LITERAL(22, 210, 3), // "pos"
QT_MOC_LITERAL(23, 214, 18), // "updateBarDirection"
QT_MOC_LITERAL(24, 233, 9), // "startGame"
QT_MOC_LITERAL(25, 243, 12), // "updateCursor"
QT_MOC_LITERAL(26, 256, 11), // "resetCursor"
QT_MOC_LITERAL(27, 268, 18) // "resetMousePosition"

    },
    "CanvasWidget\0levelComplete\0\0gameEnded\0"
    "score\0level\0elapsedTime\0focusLost\0"
    "mousePressed\0fire\0cheatSkipLevel\0"
    "cheatAddLife\0setGamePaused\0paused\0"
    "updateFireShortcut\0newGame\0showLine\0"
    "line\0lineNumber\0putGift\0gift\0times\0"
    "pos\0updateBarDirection\0startGame\0"
    "updateCursor\0resetCursor\0resetMousePosition"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_CanvasWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x06 /* Public */,
       3,    3,  100,    2, 0x06 /* Public */,
       7,    0,  107,    2, 0x06 /* Public */,
       8,    0,  108,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    0,  109,    2, 0x0a /* Public */,
      10,    0,  110,    2, 0x0a /* Public */,
      11,    0,  111,    2, 0x0a /* Public */,
      12,    1,  112,    2, 0x0a /* Public */,
      14,    0,  115,    2, 0x0a /* Public */,
      15,    0,  116,    2, 0x0a /* Public */,
      16,    2,  117,    2, 0x0a /* Public */,
      19,    3,  122,    2, 0x0a /* Public */,
      23,    0,  129,    2, 0x0a /* Public */,
      24,    0,  130,    2, 0x0a /* Public */,
      25,    0,  131,    2, 0x0a /* Public */,
      26,    0,  132,    2, 0x0a /* Public */,
      27,    0,  133,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int,    4,    5,    6,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,   17,   18,
    QMetaType::Void, QMetaType::QString, QMetaType::Int, QMetaType::QString,   20,   21,   22,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void CanvasWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        CanvasWidget *_t = static_cast<CanvasWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->levelComplete(); break;
        case 1: _t->gameEnded((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 2: _t->focusLost(); break;
        case 3: _t->mousePressed(); break;
        case 4: _t->fire(); break;
        case 5: _t->cheatSkipLevel(); break;
        case 6: _t->cheatAddLife(); break;
        case 7: _t->setGamePaused((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 8: _t->updateFireShortcut(); break;
        case 9: _t->newGame(); break;
        case 10: _t->showLine((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 11: _t->putGift((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 12: _t->updateBarDirection(); break;
        case 13: _t->startGame(); break;
        case 14: _t->updateCursor(); break;
        case 15: _t->resetCursor(); break;
        case 16: _t->resetMousePosition(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (CanvasWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CanvasWidget::levelComplete)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (CanvasWidget::*_t)(int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CanvasWidget::gameEnded)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (CanvasWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CanvasWidget::focusLost)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (CanvasWidget::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&CanvasWidget::mousePressed)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject CanvasWidget::staticMetaObject = {
    { &KgDeclarativeView::staticMetaObject, qt_meta_stringdata_CanvasWidget.data,
      qt_meta_data_CanvasWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *CanvasWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CanvasWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_CanvasWidget.stringdata0))
        return static_cast<void*>(this);
    return KgDeclarativeView::qt_metacast(_clname);
}

int CanvasWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KgDeclarativeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void CanvasWidget::levelComplete()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CanvasWidget::gameEnded(int _t1, int _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void CanvasWidget::focusLost()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CanvasWidget::mousePressed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
